@@ -16,7 +16,7 @@ from pele_platform.Utilities.Parameters.SimulationParams.site_finder import site
 from pele_platform.Utilities.Parameters.SimulationParams.PPI import ppi
 import pele_platform.Utilities.Helpers.helpers as hp
 
-LOGFILE = '"simulationLogPath" : "$OUTPUT_PATH/logFile.txt",'
+LOGFILE = '\n"simulationLogPath" : "$OUTPUT_PATH/logFile.txt",'
 
 
 class SimulationParams(
@@ -70,9 +70,13 @@ class SimulationParams(
         if "*" in args.system:
             self.system = glob.glob(args.system)[0]
             self.input = glob.glob(args.system) if not args.input else args.input
+        elif args.input and not args.system:
+            self.system = args.input[0]
+            self.input = args.input
         else:
             self.system = args.system
             self.input = args.input
+
         self.residue = args.residue
         self.chain = args.chain
         if self.adaptive:
@@ -130,7 +134,7 @@ class SimulationParams(
         self.sidechain_resolution = (
             args.sidechain_resolution
             if args.sidechain_resolution
-            else self.simulation_params.get("sidechain_resolution", 30)
+            else self.simulation_params.get("sidechain_resolution", 10)
         )
         self.proximityDetection = (
             "false"
@@ -249,6 +253,12 @@ class SimulationParams(
             self.binding_energy = ""
             self.sasa = ""
 
+        self.sidechain_radius = (
+            args.sidechain_radius
+            if args.sidechain_radius is not None
+            else self.simulation_params.get("sidechain_radius", 6)
+        )
+
     def main_adaptive_params(self, args):
         self.spawning = (
             args.spawning
@@ -301,10 +311,16 @@ class SimulationParams(
             os.path.join(os.path.dirname(os.path.dirname(__file__)), "PeleTemplates")
         )
         self.usesrun = "true" if args.usesrun else "false"
-        mpi_params_name = "srunParameters" if args.usesrun else "mpiParameters"
-        self.mpi_params = (
-            f'"{mpi_params_name}": "{args.mpi_params}",' if args.mpi_params else ""
-        )
+
+        if args.usesrun:
+            mpi_params_name = "srunParameters"
+        else:
+            mpi_params_name = "mpiParameters"
+
+        if args.pele_mpi_params is not None and args.pele_mpi_params != "":
+            self.pele_mpi_params = f'"{mpi_params_name}": "{args.pele_mpi_params}",'
+        else:
+            self.pele_mpi_params = ""
 
     def optative_params(self, args):
         if args.forcefield is None:
@@ -380,7 +396,7 @@ class SimulationParams(
         self.bandwidth = (
             args.bandwidth
             if args.bandwidth
-            else self.simulation_params.get("bandwidth", 2.5)
+            else self.simulation_params.get("bandwidth", "auto")
         )
         self.clustering_method = (
             args.clustering_method
@@ -514,6 +530,9 @@ class SimulationParams(
         self.water_ids_to_track = []
 
     def box_params(self, args):
+
+        self.box = args.box if args.box is not None else True
+
         self.box_radius = (
             args.box_radius
             if args.box_radius
@@ -573,10 +592,11 @@ class SimulationParams(
         self.cluster_representatives_criterion = (
             args.cluster_representatives_criterion
             if args.cluster_representatives_criterion is not None
-            else "interaction_5_percentile"
+            else "interaction_min"
         )
         self.clustering_filtering_threshold = args.clustering_filtering_threshold if args.clustering_filtering_threshold is not None else 0.25
         self.plot_filtering_threshold = args.plot_filtering_threshold if args.plot_filtering_threshold is not None else 0.02
+        self.clustering_coverage = args.clustering_coverage if args.clustering_coverage is not None else 0.75
 
     def constraints_params(self, args):
         """
@@ -633,9 +653,16 @@ class SimulationParams(
         """
         Sets parameters for singularity containers.
         """
-        args.mpi_params = args.singularity_exec if args.singularity_exec else args.mpi_params
+        if args.pele_mpi_params is None:
+            args.pele_mpi_params = cs.DEFAULT_PELE_MPI_PARAMS
+
         if args.singularity_exec:
-            args.pele_exec = "Pele_mpi" if not self.frag_pele else args.mpi_params + " Pele_mpi"
+            if args.pele_mpi_params != "":
+                args.pele_mpi_params = args.pele_mpi_params + ' ' + args.singularity_exec
+            else:
+                args.pele_mpi_params = args.singularity_exec
+
+            args.pele_exec = "Pele_mpi" if not self.frag_pele else args.pele_mpi_params + " Pele_mpi"
 
     def covalent_docking_params(self, args):
         """
